summaryrefslogtreecommitdiff
path: root/src/resources/resourcemanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/resources/resourcemanager.h')
-rw-r--r--src/resources/resourcemanager.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/resources/resourcemanager.h b/src/resources/resourcemanager.h
index e1aed521..28ab4725 100644
--- a/src/resources/resourcemanager.h
+++ b/src/resources/resourcemanager.h
@@ -183,13 +183,16 @@ class ResourceManager
* Allocates data into a buffer pointer for raw data loading. The
* returned data is expected to be freed using <code>free()</code>.
*
* @param fileName The name of the file to be loaded.
* @param fileSize The size of the file that was loaded.
*
* @return An allocated byte array containing the data that was loaded,
* or <code>NULL</code> on fail.
*/
- void *loadFile(const std::string &fileName, int &fileSize);
+ void *loadFile(const std::string &filename, int &filesize,
+ bool inflate = true);
/**
* Retrieves the contents of a text file.
@@ -183,13 +183,16 @@ class ResourceManager
* returned data is expected to be freed using <code>free()</code>.
*
- * @param fileName The name of the file to be loaded.
- * @param fileSize The size of the file that was loaded.
+ * @param filename The name of the file to be loaded.
+ * @param filesize The size of the file that was loaded.
+ * @param inflate True to uncompress the file if the filename ends in
+ * ".gz", false to ignore that.
*
* @return An allocated byte array containing the data that was loaded,